==> haskell-hinotify-0.4.2-81.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hinotify
version:              0.4.2
visibility:           public
id:                   hinotify-0.4.2-KBVoaFnxvyh4b67Iw9rVOg
key:                  hinotify-0.4.2-KBVoaFnxvyh4b67Iw9rVOg
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  4dee65d5bc6194dc84a4e6d875da5f35
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.2-KBVoaFnxvyh4b67Iw9rVOg
includes:             sys/inotify.h
depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hinotify-0.4.2-82-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hinotify
version:              0.4.2
visibility:           public
id:                   hinotify-0.4.2-7jy9U7hnF2eLSCmgfLuzWk
key:                  hinotify-0.4.2-7jy9U7hnF2eLSCmgfLuzWk
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  ba1093600f4bdb2e56e077aaa0084461
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.2-7jy9U7hnF2eLSCmgfLuzWk
includes:             sys/inotify.h
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
